@@ -4,17 +4,18 @@ import logging
 import re
 import warnings
 from functools import wraps, partialmethod as pm
-from typing import (Union, AnyStr, Mapping, Iterable,
-                    Optional, Callable, AsyncGenerator)
+from typing import Union, AnyStr, Mapping, Iterable, Optional, AsyncGenerator
 
 import aiohttp
 
 from . import serialization
 from .compat import pd, no_pandas_warning
-from .iterutils import InfluxDBResult, InfluxDBChunkedResult
 
-PointType = Union[AnyStr, Mapping] if pd is None else Union[AnyStr, Mapping, pd.DataFrame]
-ResultType = Union[AsyncGenerator, dict, bytes, InfluxDBResult, InfluxDBChunkedResult]
+if not pd:
+    PointType = Union[AnyStr, Mapping]
+else:
+    PointType = Union[AnyStr, Mapping, pd.DataFrame]
+ResultType = Union[AsyncGenerator, dict, bytes]
 
 # Aioinflux uses logging mainly for debugging purposes.
 # Please attach your own handlers if you need logging.
@@ -34,10 +35,12 @@ def runner(coro):
 
 
 class InfluxDBError(Exception):
+    """Raised when an server-side error occurs"""
     pass
 
 
 class InfluxDBWriteError(InfluxDBError):
+    """Raised when a server-side writing error occurs"""
     def __init__(self, resp):
         self.status = resp.status
         self.headers = resp.headers
@@ -61,36 +64,42 @@ class InfluxDBClient:
         username: Optional[str] = None,
         password: Optional[str] = None,
         database: Optional[str] = None,
-        loop: Optional[asyncio.BaseEventLoop] = None,
+        loop: Optional[asyncio.AbstractEventLoop] = None,
     ):
         """
-        The InfluxDBClient object holds information necessary to interact with InfluxDB.
+        :class:`~aioinflux.client.InfluxDBClient`  holds information necessary
+        to interact with InfluxDB.
         It is async by default, but can also be used as a sync/blocking client.
         When querying, responses are returned as parsed JSON by default,
         but can also be wrapped in easily iterable
         wrapper object or be parsed to Pandas DataFrames.
         The three main public methods are the three endpoints of the InfluxDB API, namely:
-        1) InfluxDBClient.ping
-        2) InfluxDBClient.write
-        3) InfluxDBClient.query
+
+        1. :meth:`~aioinflux.client.InfluxDBClient.ping`
+        2. :meth:`~aioinflux.client.InfluxDBClient.write`
+        3. :meth:`~aioinflux.client.InfluxDBClient.query`
+
         See each of the above methods documentation for further usage details.
+
         See also: https://docs.influxdata.com/influxdb/latest/tools/api/
 
         :param host: Hostname to connect to InfluxDB.
         :param port: Port to connect to InfluxDB.
-        :param mode: Mode in which client should run.
-            Available options are: 'async' and 'blocking'.
-            - 'async': Default mode. Each query/request to the backend will
-            - 'blocking': Behaves in sync/blocking fashion,
-                          similar to the official InfluxDB-Python client.
+        :param mode: Mode in which client should run. Available options:
+
+           - ``async``: Default mode. Each query/request to the backend will
+           - ``blocking``: Behaves in sync/blocking fashion,
+             similar to the official InfluxDB-Python client.
+
         :param output: Output format of the response received from InfluxDB.
-            - 'json': Default format. Returns parsed JSON as received from InfluxDB.
-            - 'bytes': Returns raw, non-parsed JSON binary blob as received from InfluxDB.
-                       No error checking is performed. Useful for response caching.
-            - 'iterable': Wraps the JSON response in a `InfluxDBResult` or `InfluxDBChunkedResult`,
-                          which can be used for easier iteration over retrieved data points.
-            - 'dataframe': Parses results into Pandas DataFrames.
-                           Not compatible with chunked responses.
+
+           - ``json``: Default format.
+             Returns parsed JSON as received from InfluxDB.
+           - ``bytes``: Returns raw, non-parsed JSON binary blob as received from InfluxDB.
+             No error checking is performed. Useful for response caching.
+           - ``dataframe``: Parses results into :py:class`pandas.DataFrame`.
+             Not compatible with chunked responses.
+
         :param db: Default database to be used by the client.
         :param ssl: If https should be used.
         :param unix_socket: Path to the InfluxDB Unix domain socket.
@@ -101,12 +110,14 @@ class InfluxDBClient:
         :param loop: Asyncio event loop.
         """
         self._loop = asyncio.get_event_loop() if loop is None else loop
-        self._session = aiohttp.ClientSession(
-            loop=self._loop,
-            auth=aiohttp.BasicAuth(username, password) if username and password else None,
-            connector=aiohttp.UnixConnector(path=unix_socket,
-                                            loop=self._loop) if unix_socket else None,
-        )
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore', DeprecationWarning)
+            self._session = aiohttp.ClientSession(
+                loop=self._loop,
+                auth=aiohttp.BasicAuth(username, password) if username and password else None,
+                connector=aiohttp.UnixConnector(path=unix_socket,
+                                                loop=self._loop) if unix_socket else None,
+            )
         self._url = f'{"https" if ssl else "http"}://{host}:{port}/{{endpoint}}'
         self.host = host
         self.port = port
@@ -177,7 +188,7 @@ class InfluxDBClient:
     @runner
     async def ping(self) -> dict:
         """Pings InfluxDB.
-         Returns a dictionary containing the headers of the response from `influxd`.
+         Returns a dictionary containing the headers of the response from ``influxd``.
          """
         async with self._session.get(self._url.format(endpoint='ping')) as resp:
             logger.debug(f'{resp.status}: {resp.reason}')
@@ -197,13 +208,14 @@ class InfluxDBClient:
         """Writes data to InfluxDB.
         Input can be:
 
-        1) a string properly formatted in InfluxDB's line protocol
-        2) a dictionary-like object containing four keys:
+        1. A mapping (e.g. ``dict``) containing the keys:
            ``measurement``, ``time``, ``tags``, ``fields``
-        3) a Pandas DataFrame with a DatetimeIndex
-        4) an iterable of one of above
+        2. A Pandas :class:`~pandas.DataFrame` with a :class:`~pandas.DatetimeIndex`
+        3. A user defined class decorated w/ :func:`~aioinflux.serialization.usertype.lineprotocol`
+        4. A string (``str`` or ``bytes``) properly formatted in InfluxDB's line protocol
+        5. An iterable of one of the above
 
-        Input data in formats 2-4 are parsed to the line protocol before being written to InfluxDB.
+        Input data in formats 1-3 are parsed to the line protocol before being written to InfluxDB.
         See the `InfluxDB docs <https://docs.influxdata.com/influxdb/latest/
         write_protocols/line_protocol_reference/>`_ for more details.
 
@@ -219,7 +231,7 @@ class InfluxDBClient:
             data is written to the default retention policy.
         :param tag_columns: Columns to be treated as tags (used when writing DataFrames only)
         :param extra_tags: Additional tags to be added to all points passed.
-        :return: Returns `True` if insert is successful. Raises `ValueError` exception otherwise.
+        :return: Returns ``True`` if insert is successful. Raises :py:class:`ValueError` otherwise.
         """
         if precision is not None:
             # FIXME: Implement. Related issue: aioinflux/pull/13
@@ -244,7 +256,6 @@ class InfluxDBClient:
         chunked: bool = False,
         chunk_size: Optional[int] = None,
         db: Optional[str] = None,
-        parser: Optional[Callable] = None,
         **kwargs,
     ) -> ResultType:
         """Sends a query to InfluxDB.
@@ -263,8 +274,8 @@ class InfluxDBClient:
             responses by series or by every 10,000 points, whichever occurs first.
         :param kwargs: Keyword arguments for query patterns
         :param parser: Optional parser function for 'iterable' mode
-        :return: Returns an async generator if chunked is ``True``, otherwise returns
-            a dictionary containing the parsed JSON response.
+        :return: Response in the format specified by the combination of
+           ``InfluxDBClient.output`` and ``chunked``
         """
 
         # noinspection PyShadowingNames
@@ -305,8 +316,6 @@ class InfluxDBClient:
             g = _chunked_generator(url, data)
             if self.output in ('bytes', 'json'):
                 return g
-            elif self.output == 'iterable':
-                return InfluxDBChunkedResult(g, parser=parser, query=query)
             elif self.output == 'dataframe':
                 raise ValueError("Chunked queries are not support with 'dataframe' output")
 
@@ -322,10 +331,8 @@ class InfluxDBClient:
             self._check_error(output)
             if self.output == 'json':
                 return output
-            elif self.output == 'iterable':
-                return InfluxDBResult(output, parser=parser, query=query)
             elif self.output == 'dataframe':
-                return serialization.dataframe.serialize(output)
+                return serialization.dataframe.parse(output)
 
     @staticmethod
     def _check_error(response):
@@ -369,6 +376,10 @@ class InfluxDBClient:
         :param name: Name of the query pattern class method. Must be a valid Python identifier.
         :param qp: Query pattern string
         """
+        warnings.warn("'set_query_pattern' is deprecated and "
+                      "will be removed in a future version. "
+                      "Define query patterns as functions in your own code instead.",
+                      DeprecationWarning, stacklevel=2)
         restricted_kwargs = ('q', 'epoch', 'chunked' 'chunk_size', 'parser')
         if any(kw in restricted_kwargs for kw in re.findall(r'{(\w+)}', qp)):
             warnings.warn(f'Ignoring invalid query pattern: {qp}')
