@@ -1,10 +1,9 @@
-# flake8: noqa
+# flake8: noqa 402
 from ..compat import pd
 
 if pd:
     from . import dataframe
 from . import mapping
-from .datapoint import DataPoint
 
 
 def serialize(data, measurement=None, tag_columns=None, **extra_tags):
@@ -13,14 +12,14 @@ def serialize(data, measurement=None, tag_columns=None, **extra_tags):
         return data
     elif isinstance(data, str):
         return data.encode('utf-8')
-    elif isinstance(data, DataPoint):
+    elif hasattr(data, 'to_lineprotocol'):
         return data.to_lineprotocol()
     elif pd is not None and isinstance(data, pd.DataFrame):
         if measurement is None:
             raise ValueError("Missing 'measurement'")
-        return dataframe.parse(data, measurement, tag_columns, **extra_tags)
+        return dataframe.serialize(data, measurement, tag_columns, **extra_tags)
     elif isinstance(data, dict):
-        return mapping.serialize(data, measurement, **extra_tags).encode('utf-8')
+        return mapping.serialize(data, measurement, **extra_tags)
     elif hasattr(data, '__iter__'):
         return b'\n'.join([serialize(i, measurement, tag_columns, **extra_tags) for i in data])
     else:
